pub struct HFRepositoryGetFileMetadataBuilder<'f1, 'f2, T: RepoType, S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with send().
Implementations
Sourceimpl<'f1, 'f2, T: RepoType, S: State> HFRepositoryGetFileMetadataBuilder<'f1, 'f2, T, S>
impl<'f1, 'f2, T: RepoType, S: State> HFRepositoryGetFileMetadataBuilder<'f1, 'f2, T, S>
Sourcepub async fn send(self) -> HFResult<FileMetadataInfo>where
S: IsComplete,
pub async fn send(self) -> HFResult<FileMetadataInfo>where
S: IsComplete,
Finishes building and performs the requested action.
Sourcepub fn filepath(
self,
value: impl Into<String>,
) -> HFRepositoryGetFileMetadataBuilder<'f1, 'f2, T, SetFilepath<S>>where
S::Filepath: IsUnset,
pub fn filepath(
self,
value: impl Into<String>,
) -> HFRepositoryGetFileMetadataBuilder<'f1, 'f2, T, SetFilepath<S>>where
S::Filepath: IsUnset,
Required.
Path of the file to inspect within the repository.
Sourcepub fn revision(
self,
value: &'f2 str,
) -> HFRepositoryGetFileMetadataBuilder<'f1, 'f2, T, SetRevision<S>>where
S::Revision: IsUnset,
pub fn revision(
self,
value: &'f2 str,
) -> HFRepositoryGetFileMetadataBuilder<'f1, 'f2, T, SetRevision<S>>where
S::Revision: IsUnset,
Sourcepub fn maybe_revision(
self,
value: Option<&'f2 str>,
) -> HFRepositoryGetFileMetadataBuilder<'f1, 'f2, T, SetRevision<S>>where
S::Revision: IsUnset,
pub fn maybe_revision(
self,
value: Option<&'f2 str>,
) -> HFRepositoryGetFileMetadataBuilder<'f1, 'f2, T, SetRevision<S>>where
S::Revision: IsUnset,