CacheRepo

Struct CacheRepo 

pub struct CacheRepo { /* private fields */ }
Shorthand for accessing things within a particular repo

Implementations

Source

impl CacheRepo

pub fn get(&self, filename: &str) -> Option<PathBuf>

This will get the location of the file within the cache for the remote filename. Will return None if file is not already present in cache.

pub fn create_ref(&self, commit_hash: &str) -> Result<(), Error>

Creates a reference in the cache directory that points branches to the correct commits within the blobs.

pub fn blob_path(&self, etag: &str) -> PathBuf

Get the path of the blob with the given etag.

pub fn pointer_path(&self, commit_hash: &str) -> PathBuf

Get the path of the snapshot with the given commit hash.

This path contains symlink pointers to the files for this commit.